@@ -1,8 +1,11 @@
 """Experimental module to automatically install Friendly
 as a replacement for the standard traceback in IPython."""
+import sys
+
 try:
     from IPython.core import interactiveshell as shell  # noqa
-    from IPython.core import compilerop  # noqa
+    from IPython.core import compilerop, magic  # noqa
+    from IPython.core.formatters import PlainTextFormatter  # noqa
 except ImportError:
     raise ValueError("IPython cannot be imported.")
 
@@ -18,8 +21,9 @@ from friendly_traceback import (
 from friendly_traceback.config import session
 
 from friendly.rich_console_helpers import *  # noqa
-from friendly.rich_console_helpers import helpers
-from friendly import __version__ as version
+from friendly.rich_console_helpers import helpers, current_lang  # noqa
+from friendly import __version__ as version  # noqa
+from friendly import current_lang  # noqa
 
 try:
     from IPython.utils import py3compat  # noqa
@@ -28,11 +32,11 @@ try:
 except Exception:  # noqa
     pass
 
+_ = current_lang.translate
 colorama.deinit()
 colorama.init(convert=False, strip=False)
 session.ipython_prompt = True
 
-
 shell.InteractiveShell.showtraceback = lambda self, *args, **kwargs: explain_traceback()
 shell.InteractiveShell.showsyntaxerror = (
     lambda self, *args, **kwargs: explain_traceback()
@@ -43,8 +47,12 @@ install(include="friendly_tb")
 
 # By default, we assume a terminal with a dark background.
 set_formatter("dark")  # noqa
-__all__ = list(helpers.keys())
-
 print(
     f"friendly_traceback {__version__}; friendly {version}.\nType 'Friendly' for information."
 )
+
+
+if session.exception_before_import:
+    if session.saved_info:
+        session.saved_info.pop()
+    session.get_traceback_info(sys.last_type, sys.last_value, sys.last_traceback)
