@@ -1,6 +1,7 @@
 """Mu's repl uses an IPython QtConsole.
 Mu has three themes designated (in English) as 'day', 'night',
 and 'high contrast'."""
+import sys
 
 import colorama  # noqa
 from friendly_traceback import set_stream
@@ -60,8 +61,10 @@ helpers["set_width"] = set_width
 # ========= Replacing theme-based formatters
 del helpers["dark"]
 del helpers["light"]
+del helpers["plain"]
 Friendly.remove_helper("dark")
 Friendly.remove_helper("light")
+Friendly.remove_helper("plain")
 
 
 def day():
@@ -80,17 +83,17 @@ def black():
 
 
 def bw():
-    """Black and white."""
+    """White text on black background."""
     set_formatter("repl", background="#000000")
 
 
 short_description["day"] = lambda: _("Colour scheme designed for Mu's day theme.")
 short_description["night"] = lambda: _("Colour scheme designed for Mu's night theme.")
 short_description["black"] = lambda: _(
-    "Colourful scheme designed for Mu's high contrast theme."
+    "Colourful scheme with black background suitable for Mu's high contrast theme."
 )
 short_description["bw"] = lambda: _(
-    "Black and white scheme designed for Mu's high contrast theme."
+    "White text on black background; suitable for Mu's high contrast theme."
 )
 local_helpers = {"day": day, "night": night, "black": black, "bw": bw}
 add_help_attribute(local_helpers)
@@ -100,3 +103,9 @@ for helper in local_helpers:
 helpers.update(local_helpers)
 __all__ = list(helpers.keys())
 day()
+
+if session.exception_before_import:
+    if session.saved_info:
+        session.saved_info.pop()
+    session.get_traceback_info(sys.last_type, sys.last_value, sys.last_traceback)
+    friendly_tb()  # noqa
